<?php

namespace Hris\NursingBundle\Controller;

use Hris\LeaveBundle\Form\LeaveReportType;
use Hris\NursingBundle\Form\NursingDistributionType;
use Hris\NursingBundle\Form\PopulationDistributionType;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Hris\OrganisationunitBundle\Entity\Organisationunit;
use Hris\FormBundle\Entity\Form;
use Hris\FormBundle\Entity\Field;
use Hris\FormBundle\Entity\FieldOption;
use Hris\ReportsBundle\Form\ReportHistoryTrainingType;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Doctrine\Common\Collections\ArrayCollection;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Hris\ReportsBundle\Entity\Report;
use Hris\ReportsBundle\Form\ReportType;
use Ob\HighchartsBundle\Highcharts\Highchart;
use Zend\Json\Expr;
use JMS\SecurityExtraBundle\Annotation\Secure;


/**
 * NursingReport controller.
 *
 * @Route("/populationReport")
 */
class PopulationController extends Controller
{
    /**
     * Show Leave Report Records Form
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_REPORTRECORDS_LIST")
     * @Route("/", name="population_distribution_report")
     * @Method("GET")
     * @Template()
     */
    public function indexAction()
    {
        $distributionReportForm = $this->createForm(new PopulationDistributionType($this->getUser()),null,array('em'=>$this->getDoctrine()->getManager()));
        return array(
            'departmentReportForm'=>$distributionReportForm->createView(),
        );
    }

    /**
     * Show Leave Report Records Form
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_REPORTRECORDS_LIST")
     * @Route("/jsondata", name="jsondata")
     * @Method("GET")
     * @Template()
     */
    public function jsonDataAction()
    {
        return $this->render(
            'HrisNursingBundle:Population:data.html.twig');
    }

    /**
     * Generate aggregated reports
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_REPORTHISTORY_GENERATE")
     * @Route("/", name="distribution_nurses_generate")
     * @Method("PUT")
     * @Template()
     */
    public function generateAction(Request $request)
    {
        $serializer = $this->container->get('serializer');
        $distributionReportForm = $this->createForm(new NursingDistributionType($this->getUser()),null,array('em'=>$this->getDoctrine()->getManager()));
        $distributionReportForm->bind($request);

            $nursingReportFormData = $distributionReportForm->getData();
            $organisationUnit = $nursingReportFormData['distributionLevel'];
            $region = $nursingReportFormData['region'];
            $forms = $nursingReportFormData['forms'];
            $licence = $nursingReportFormData['NursesLicencing'];
            $NursingCadre = $nursingReportFormData['NursingCadre'];
        $year = $nursingReportFormData["Year"];
        $reportType = $nursingReportFormData["IndicatorType"];
        //creating forms array
        $formsArray = array();
        $formString="";
        foreach($forms as $form){
            $formsArray[] = $form->getId();
            $formString .= $form->getId()."_";
        }

        $regionArray = array();
        $regionString = "";
        foreach($region as $prof){
            $regionArray[] = $prof;
            $regionString .= $prof."_";
        }

        //creating carde string for excel export
        $cardetring= "";
        $cardetring .= $NursingCadre;
        //creating licence string for excel export
        $licencestring= "";
        $licencestring .= $licence;

        //craeting a title
        $licensetitle ="";
        if($licence == "Licensed"){
            $licensetitle = " Licensed ";
        }elseif($licence == "NotLicensed"){
            $licensetitle = "Not Licenced";
        }else{

        }
        if($NursingCadre != ""){
            $title = $NursingCadre." Nurses ";
        }else{
            $title = "Nurses";
        }



        //Get the Id for the form
//        $formsId = $forms->getId();
        $results = $this->nursingRecords($regionArray, $formsArray,$NursingCadre,$licence,$organisationUnit);
        $serializer = $this->container->get('serializer');
        $departmentName = array();
        $departmentData = array();
        $dataArray   = array();
        foreach($results as $result){
            $departmentName[] = $result['data'];
            $departmentData[] = $result['total'];
            $dataArray[$result['data']] = $result['total'];
        }
        $jsondata = '{"headers":[{"name":"pe","column":"Period","type":"java.lang.String","hidden":false,"meta":true},{"name":"dx","column":"Data","type":"java.lang.String","hidden":false,"meta":true},{"name":"ou","column":"Organisation unit","type":"java.lang.String","hidden":false,"meta":true},{"name":"value","column":"Value","type":"java.lang.Double","hidden":false,"meta":false}],"metaData":{"pe":["2013","2014"],"co":["ddmrU8qJa7L","MEnWr4qPKRZ","uV2VZgwcBwl","oliDewHdUdd","dtdut9EncYH","p6WUey2PJZs","jCDS9573aXj","cDJ9PFr9uzM","uuidY4WdJml","GU5Za7lqR8B","R0vtSj3dkk6","MQKsgFxCtJ7","kSxbMW8Lmsd","n15V8E7ZLT9","cSd5i1BGcxv","R33m4bJ5OcC","R9Ka4Hd70Wh","Ak7SvGtlnWp","PSQ2DsGun8c","PvCDQOjeMDy","awkJLkKHr7a","ky6G1LXLxps","sgG28zSclZm","iaPGviZZIky","e0RdqwlP1Xj","xo7RVsgBkpT"],"ou":["plSLZJGUHZb","e3ATlebHNrD","saOGTLvMX4F","AiyppObGUqI","WgQHWeMx6Zl","Hob4dzCAW2W","Kug5uWxs0mu","GbVBjR8A7aK","fSZfOuCkmAb","WB7EAwS3F8N","Ak1TMj0oYc7","dIiTyLaZAEb","aiZstwpkrny","gOcZSwBmijY","jupsOTyKi1W","SnczTnCrk6d","G2obPNftMUt","B9idcF4fOIW","z4dfv9EOq3c","tNFOa31xGhu","C96DDKK03pu","QekURU8eIU0","dPzNEI2Cxqj","F8NIzb16wVU","GI57B0uNPOX","kISvf8gGZMm","yiR1QdOwPqP","aQEZnk4RzKv","uPphu8kRXoZ","bDteRg6tH0A","vU0Qt1A5IDz","N5FKtARi6dB","X5MzEu84hUN","QBC1po2JaJW","PHGm198Hcil","QUTWca9YxNb","jAI2fd8kK1z","P1TuGaaZ981","mbXn83McbCh","WCTbfnMiNF3","Srvx9L1LGZM","IfQ2Sjbfdme","dGtH1WiNUrP","Yb483pDzzWj","gu92DYtO3ii","sWOWPBvwNY2","rQS2cX4JH88","wIjscdPZF3N","Qp6ocX9ESSa","A54bflEH57w","duES2Gfgvpw","dWfRpHKykpk","qHJkyM0bG8U","O8O3HQdJWHX","QE0OH5162nV","qg5ySBw9X5l","LGTVRhKSn1V","T3A9X81ABG3","OzGGHqXQn5p","wsCWwNbLJNY","ouZ5YpZ4T3a","LoPF5WqswyW","RD96nI1JXVV","cb9rqgLXFeh","K8HUKJUZ7aj","XLrownkhsKI","VdIZ0pAYfBK","IGSrsG5I54W","MiLb81EwC7j","mOqc3ajETpA","PKl52zU7vuH","iEIdCVxSJct","xOJxkz079Ek","lQOxGNRaklm","ppnbxB0TxjG","Cpd5l15XxwA","RHLUbsrsFoE","sjKfO239rjD","xRx7W86ElUH","DWSo42hunXH","dFCrIa5paz7","d07Wtk7brGz","L9scGbK6d61","r9NgS2Jsu9I","Nc1C12TG69d","xe93MrFXOYV","xVzeWrXHf81","Qyg5jjxGeQD","N8oGVhuoUcK","gncV3iPt6Sk","PvqxGEssig9","tLzrq5IZ23W","Fez1Dp8bXSk","cnsiTXSJqqF","f7UPzYMgzVH","HIOQoi1aeL8","GOmwoDIGL98","oMao5qA3DBy","vo788oc0NEn","L5AfyN2zxns","et6lWc8GDHy","NzvekEmEzUG","TO89Eu9qoSX","yyW17iCz9As","mKI72g04l0D","cjlkhW8VMDO","QeMjl7Ld0Vj","P5H056daq2I","ZYYX8Q9SGoV","nUFAmN93pH4","dt0Q0NhyPty","fogigwn9cW7","I58Bh8dN2sO","Le7ysFRJrMk","VMgrQWSVIYn","H2LvCkw2bCO","yPCs2xE66we","cZMveFzVrXh","VMTJLxcFH9o","LbM25p7KBDP","m2ux1UEElNB","LdzOZ9hNTwH","vQvBfxn7Cjs","yh0b4OAgg8z","RCDM6DotMZw","yTTjcYh4xqa","btLScg6XCBN","vYT08q7Wo33","WAwWjYYzdkS","cirtJ7KuNU0","ZszYGa2Vnyc","Q16E1rzDnVD","DkxlFk8MuM7","XL0luikY9oG","ySuyuvNNFp8","PEIzWSzWQ7S","G9VxK1Dmkpc","bN5q5k5DgLA","uHp3aLKA6Tn","AvfNRAIsvhg","uafqZbOYpVL","aVLidCZ2RYk","hAFRrgDK0fy","BVBmQDCexxG","YFPElmUhUok","bRz3nu8rSWS","vAtZ8a924Lx","zfwo4rq1XC3","QKEr8DFutO8","W884lMlfpca","OHu1VHzyA0x","Crkg9BoUo5w","m4ow47nd3DC","rrHtwyYjprs","zHa2ohFrpPM","IYqT1Xik8Bj","NzVLQOcSJJU","PF4defRibDi","aa5sxEFiAwN","vJY7WRfb5Hc","IZAkMaffRh8","D21VsjNL2LB","IgTAEKMqKRe","xBWOfftpkLT","yz7jPBCDXlX","PM74xoecSpJ","bKA4yc2NUxA","lnOyHhoLzre","ts6eEeUjcfO","aouUIozrc7I","aMnC7MINXlM","qarQhOt2OEh","EO3Ps3ny0Nr","FylvwNXCTAQ","acZHYslyJLt","lgZ6HfZaj3f","MAL4cfZoFhJ","Y8sOGpb4AFE","Sj50oz9EHvD","YtVMnut7Foe","ilY7TEjviqa","tcZz4Bh4mqc","DTc1rxSmlde","V60DkMrlQ5Q","kZ6RlMnt2bp","OOplITY83ud","PHWaJvzTmL8","A3b5mw8DJYC"],"names":{"yyW17iCz9As":"Pwani Region","IZAkMaffRh8":"Chato District Council","G9VxK1Dmkpc":"Nyanghwale District Council","f7UPzYMgzVH":"Nyamagana Municipal Council","QE0OH5162nV":"Ukerewe District Council","yiR1QdOwPqP":"Chamwino District Council","IfQ2Sjbfdme":"Kasulu Town Council","dtdut9EncYH":"(KE, Umri mwaka 1 hadi umri chini ya miaka 5, IPD)","et6lWc8GDHy":"Ilemela Municipal Council","vQvBfxn7Cjs":"Msalala District Council","lQOxGNRaklm":"Kigoma District Council","Kug5uWxs0mu":"Magu District Council","cnsiTXSJqqF":"Babati Town Council","aMnC7MINXlM":"Siha District Council","OzGGHqXQn5p":"Dodoma Municipal Council","hAFRrgDK0fy":"Mwanza Region","plSLZJGUHZb":"Bukombe District Council","r9NgS2Jsu9I":"Tunduru District Council","2013":"2013","2014":"2014","A3b5mw8DJYC":"Mbeya Region","jAI2fd8kK1z":"Misungwi District Council","EO3Ps3ny0Nr":"Shinyanga Region","V60DkMrlQ5Q":"Singida Municipal Council","Y8sOGpb4AFE":"Moshi Municipal Council","YFPElmUhUok":"Karagwe District Council","cZMveFzVrXh":"Sumbawanga Municipal Council","H2LvCkw2bCO":"Muheza District Council","wIjscdPZF3N":"Muleba District Council","W884lMlfpca":"Nachingwea District Council","xOJxkz079Ek":"Mtwara District Council","OHu1VHzyA0x":"Mwanga District Council","T3A9X81ABG3":"Kakonko District Council","AvfNRAIsvhg":"Mbarali District Council","dx":"Data","G2obPNftMUt":"Morogoro District Council","dPzNEI2Cxqj":"Rungwe District Council","A54bflEH57w":"Simanjiro District Council","WCTbfnMiNF3":"Same District Council","mKI72g04l0D":"Kilindi District Council","qHJkyM0bG8U":"Korogwe Town Council","R0vtSj3dkk6":"(5-14, KE)","rrHtwyYjprs":"Masasi District Council","kSxbMW8Lmsd":"(KE, Umri mwaka 1 hadi umri chini ya miaka 5, OPD)","NzvekEmEzUG":"Makete District Council","MiLb81EwC7j":"Hai District Council","Yut5amdi7iw":"Attendance in OPD","I58Bh8dN2sO":"Busega District Council","NzVLQOcSJJU":"Tarime District Council","ts6eEeUjcfO":"Kinondoni Municipal Council","qg5ySBw9X5l":"Manyara Region","vo788oc0NEn":"Iringa Municipal Council","RCDM6DotMZw":"Mbogwe District Council","e3ATlebHNrD":"Mbeya City Council","cjlkhW8VMDO":"Mlele District Council","lnOyHhoLzre":"Kilimanjaro Region","VMgrQWSVIYn":"Lindi Region","XL0luikY9oG":"Namtumbo District Council","QKEr8DFutO8":"Karatu District Council","DWSo42hunXH":"Katavi Region","fogigwn9cW7":"Igunga District Council","ouZ5YpZ4T3a":"Bunda District Council","LGTVRhKSn1V":"Singida Region","lgZ6HfZaj3f":"Arusha City Council","duES2Gfgvpw":"Kibondo District Council","vJY7WRfb5Hc":"Meatu District Council","mOqc3ajETpA":"Sikonge District Council","GU5Za7lqR8B":"(ME, 15-49)","yTTjcYh4xqa":"Kondoa District Council","gu92DYtO3ii":"Bumbuli District Council","bKA4yc2NUxA":"Musoma Municipal Council","F8NIzb16wVU":"Missenyi District Council","m4ow47nd3DC":"Wangingombe District Council","dGtH1WiNUrP":"Kilwa District Council","acZHYslyJLt":"Dar Es Salaam Region","uafqZbOYpVL":"Meru District Council","cb9rqgLXFeh":"Sumbawanga District Council","N8oGVhuoUcK":"Kibaha District Council","zHa2ohFrpPM":"Arusha District Council","ZszYGa2Vnyc":"Liwale District Council","Fez1Dp8bXSk":"Chemba District Council","O8O3HQdJWHX":"Kwimba District Council","QeMjl7Ld0Vj":"Kalambo District Council","PvCDQOjeMDy":"(KE, > 50)","awkJLkKHr7a":"(Umri miaka 5 au zaidi, KE, IPD)","VMTJLxcFH9o":"Moshi District Council","Sj50oz9EHvD":"Morogoro Region","sgG28zSclZm":"(Umri miaka 5 au zaidi, KE, OPD)","XLrownkhsKI":"Ngara District Council","K8HUKJUZ7aj":"Urambo District Council","xVzeWrXHf81":"Busokelo District Council","iaPGviZZIky":"(ME, Umri mwezi 1 hadi umri chini ya mwaka 1, IPD)","saOGTLvMX4F":"Geita District Council","AiyppObGUqI":"Kahama Town Council","qarQhOt2OEh":"Njombe Region","HIOQoi1aeL8":"Temeke Municipal Council","uHp3aLKA6Tn":"Manyoni District Council","PKl52zU7vuH":"Nsimbo District Council","dWfRpHKykpk":"Kyela District Council","tcZz4Bh4mqc":"Iringa District Council","Nc1C12TG69d":"Tabora Municipal Council","oMao5qA3DBy":"Kilombero District Council","DkxlFk8MuM7":"Handeni District Council","BVBmQDCexxG":"Mvomero District Council","kZ6RlMnt2bp":"Tabora Region","z4dfv9EOq3c":"Musoma District Council","cirtJ7KuNU0":"Makambako Town Council","ilY7TEjviqa":"Lushoto District Council","gOcZSwBmijY":"Tandahimba District Council","IYqT1Xik8Bj":"Newala District Council","bRz3nu8rSWS":"Rorya District Council","PHWaJvzTmL8":"Ngorongoro District Council","dIiTyLaZAEb":"Kigoma Municipal Council","btLScg6XCBN":"Butiama District Council","PHGm198Hcil":"Mtwara Municipal Council","FylvwNXCTAQ":"Shinyanga District Council","Qyg5jjxGeQD":"Mkalama District Council","PF4defRibDi":"Shinyanga Municipal Council","aVLidCZ2RYk":"Mpanda District Council","yh0b4OAgg8z":"Gairo District Council","jupsOTyKi1W":"Mpanda Town Council","IgTAEKMqKRe":"Simiyu Region","PEIzWSzWQ7S":"Kaliua District Council","WB7EAwS3F8N":"Mbinga District Council","vYT08q7Wo33":"Mara Region","rQS2cX4JH88":"Pangani District Council","uV2VZgwcBwl":"(KE, 15-49)","aa5sxEFiAwN":"Ludewa District Council","cDJ9PFr9uzM":"(ME, > 50)","aQEZnk4RzKv":"Longido District Council","uuidY4WdJml":"(KE, IPD, Umri chini ya mwezi 1)","LdzOZ9hNTwH":"Kyerwa District Council","MQKsgFxCtJ7":"(Umri miaka 5 au zaidi, ME, IPD)","Ak1TMj0oYc7":"Bahi District Council","ou":"Organisation unit","R33m4bJ5OcC":"(ME, Umri mwaka 1 hadi umri chini ya miaka 5, IPD)","R9Ka4Hd70Wh":"(KE, Umri mwezi 1 hadi umri chini ya mwaka 1, OPD)","Yb483pDzzWj":"Bariadi Town Council","tNFOa31xGhu":"Iramba District Council","PSQ2DsGun8c":"(ME, Umri mwaka 1 hadi umri chini ya miaka 5, OPD)","QBC1po2JaJW":"Korogwe District Council","uPphu8kRXoZ":"Bagamoyo District Council","P5H056daq2I":"Mpwapwa District Council","pe":"Period","bN5q5k5DgLA":"Mtwara Region","ySuyuvNNFp8":"Tanga City Council","ky6G1LXLxps":"(5-14, ME)","YtVMnut7Foe":"Arusha Region","B9idcF4fOIW":"Mkinga District Council","Srvx9L1LGZM":"Mkuranga District Council","nUFAmN93pH4":"Morogoro Municipal Council","vU0Qt1A5IDz":"Tanga Region","PvqxGEssig9":"Nanyumbu District Council","D21VsjNL2LB":"Monduli District Council","ZYYX8Q9SGoV":"Ruvuma Region","VdIZ0pAYfBK":"Songea Municipal Council","oliDewHdUdd":"(ME, IPD, Umri chini ya mwezi 1)","Crkg9BoUo5w":"Kagera Region","p6WUey2PJZs":"(ME, 1-4)","jCDS9573aXj":"(ME, < 1)","L9scGbK6d61":"Chunya District Council","ppnbxB0TxjG":"Mufindi District Council","n15V8E7ZLT9":"(ME, Umri mwezi 1 hadi umri chini ya mwaka 1, OPD)","L5AfyN2zxns":"Babati District Council","m2ux1UEElNB":"Uyui District Council","LbM25p7KBDP":"Songea District Council","d07Wtk7brGz":"Momba District Council","cSd5i1BGcxv":"(KE, < 1)","PM74xoecSpJ":"Bukoba Municipal Council","LoPF5WqswyW":"Bukoba District Council","GOmwoDIGL98":"Njombe District Council","xRx7W86ElUH":"Hanang District Council","ykShMtNgDB1":"Population","sjKfO239rjD":"Lindi District Council","QUTWca9YxNb":"Njombe Town Council","xo7RVsgBkpT":"(ME, Umri chini ya mwezi 1, OPD)","e0RdqwlP1Xj":"(KE, Umri mwezi 1 hadi umri chini ya mwaka 1, IPD)","QekURU8eIU0":"Kibaha Town Council","dt0Q0NhyPty":"Uvinza District Council","ddmrU8qJa7L":"(Umri miaka 5 au zaidi, ME, OPD)","MEnWr4qPKRZ":"(KE, 1-4)","tLzrq5IZ23W":"Masasi Town Council","vAtZ8a924Lx":"Rukwa Region","IGSrsG5I54W":"Sengerema District Council","RD96nI1JXVV":"Kigoma Region","wsCWwNbLJNY":"Ileje District Council","aouUIozrc7I":"Mbozi District Council","fSZfOuCkmAb":"Geita Town council","TO89Eu9qoSX":"Nyasa District Council","WgQHWeMx6Zl":"Ushetu District Council","xBWOfftpkLT":"Kilolo District Council","Q16E1rzDnVD":"Bariadi District Council","gncV3iPt6Sk":"Rufiji District Council","OOplITY83ud":"Ruangwa District Council","sWOWPBvwNY2":"Iringa Region","N5FKtARi6dB":"Mbeya District Council","kISvf8gGZMm":"Kishapu District Council","Le7ysFRJrMk":"Ulanga District Council","yPCs2xE66we":"Buhigwe District Council","RHLUbsrsFoE":"Singida District Council","mbXn83McbCh":"Maswa District Council","yz7jPBCDXlX":"Biharamulo District Council","zfwo4rq1XC3":"Kasulu District Council","GbVBjR8A7aK":"Kilosa District Council","P1TuGaaZ981":"Kiteto District Council","DTc1rxSmlde":"Kongwa District Council","Cpd5l15XxwA":"Dodoma Region","WAwWjYYzdkS":"Nzega District Council","MAL4cfZoFhJ":"Geita Region","X5MzEu84hUN":"Serengeti District Council","SnczTnCrk6d":"Kisarawe District Council","aiZstwpkrny":"Lindi Municipal Council","C96DDKK03pu":"Mbulu District Council","GI57B0uNPOX":"Mafia District Council","dFCrIa5paz7":"Ikungi District Council","xe93MrFXOYV":"Ilala Municipal Council","Ak7SvGtlnWp":"(KE, Umri chini ya mwezi 1, OPD)","bDteRg6tH0A":"Itilima District Council","iEIdCVxSJct":"Nkasi District Council","Hob4dzCAW2W":"Rombo District Council","Qp6ocX9ESSa":"Tarime Town Council"}},"rows":[["2014","Yut5amdi7iw","yPCs2xE66we","61083.0"],["2014","ykShMtNgDB1","acZHYslyJLt","4671427.0"],["2013","Yut5amdi7iw","SnczTnCrk6d","114109.0"],["2014","ykShMtNgDB1","G9VxK1Dmkpc","156237.0"],["2014","ykShMtNgDB1","rrHtwyYjprs","254017.0"],["2014","Yut5amdi7iw","sWOWPBvwNY2","428481.0"],["2014","ykShMtNgDB1","m4ow47nd3DC","164425.0"],["2013","Yut5amdi7iw","wsCWwNbLJNY","8834.0"],["2014","Yut5amdi7iw","PKl52zU7vuH","37196.0"],["2014","ykShMtNgDB1","aQEZnk4RzKv","129985.0"],["2013","Yut5amdi7iw","yPCs2xE66we","23116.0"],["2013","ykShMtNgDB1","ppnbxB0TxjG","321246.0"],["2013","Yut5amdi7iw","VMTJLxcFH9o","4692.0"],["2013","ykShMtNgDB1","z4dfv9EOq3c","215810.0"],["2013","Yut5amdi7iw","IYqT1Xik8Bj","107665.0"],["2014","Yut5amdi7iw","XLrownkhsKI","69369.0"],["2013","ykShMtNgDB1","zHa2ohFrpPM","332042.0"],["2014","Yut5amdi7iw","P1TuGaaZ981","54463.0"],["2013","Yut5amdi7iw","Le7ysFRJrMk","577.0"],["2013","ykShMtNgDB1","FylvwNXCTAQ","341514.0"],["2013","ykShMtNgDB1","mbXn83McbCh","350376.0"],["2014","ykShMtNgDB1","dFCrIa5paz7","285808.0"],["2013","ykShMtNgDB1","B9idcF4fOIW","120691.0"],["2013","ykShMtNgDB1","mOqc3ajETpA","185175.0"],["2013","Yut5amdi7iw","xRx7W86ElUH","17045.0"],["2013","ykShMtNgDB1","QeMjl7Ld0Vj","214025.0"],["2014","Yut5amdi7iw","PF4defRibDi","182550.0"],["2013","ykShMtNgDB1","xOJxkz079Ek","230755.0"],["2013","Yut5amdi7iw","mbXn83McbCh","118710.0"],["2014","ykShMtNgDB1","xOJxkz079Ek","233537.0"],["2014","Yut5amdi7iw","bN5q5k5DgLA","881829.0"],["2013","ykShMtNgDB1","Cpd5l15XxwA","2127807.0"],["2014","ykShMtNgDB1","Hob4dzCAW2W","270530.0"],["2014","Yut5amdi7iw","dGtH1WiNUrP","120701.0"],["2014","ykShMtNgDB1","cnsiTXSJqqF","99064.0"],["2013","ykShMtNgDB1","PKl52zU7vuH","144131.0"],["2013","Yut5amdi7iw","P5H056daq2I","192354.0"],["2014","Yut5amdi7iw","bRz3nu8rSWS","79710.0"],["2014","Yut5amdi7iw","LoPF5WqswyW","74652.0"],["2013","ykShMtNgDB1","N5FKtARi6dB","313675.0"],["2014","ykShMtNgDB1","bN5q5k5DgLA","1301719.0"],["2013","ykShMtNgDB1","TO89Eu9qoSX","149261.0"],["2014","Yut5amdi7iw","duES2Gfgvpw","73521.0"],["2013","ykShMtNgDB1","HIOQoi1aeL8","1447726.0"],["2013","Yut5amdi7iw","GOmwoDIGL98","13451.0"],["2014","Yut5amdi7iw","aMnC7MINXlM","71419.0"],["2014","ykShMtNgDB1","yiR1QdOwPqP","344722.0"],["2014","Yut5amdi7iw","rrHtwyYjprs","192824.0"],["2013","ykShMtNgDB1","qg5ySBw9X5l","1468533.0"],["2014","ykShMtNgDB1","yz7jPBCDXlX","344177.0"],["2013","ykShMtNgDB1","vYT08q7Wo33","1788153.0"],["2013","ykShMtNgDB1","wsCWwNbLJNY","127858.0"],["2013","ykShMtNgDB1","aQEZnk4RzKv","126523.0"],["2014","Yut5amdi7iw","K8HUKJUZ7aj","26166.0"],["2014","Yut5amdi7iw","WCTbfnMiNF3","25829.0"],["2013","Yut5amdi7iw","vJY7WRfb5Hc","142449.0"],["2013","ykShMtNgDB1","WB7EAwS3F8N","361188.0"],["2014","ykShMtNgDB1","aVLidCZ2RYk","190594.0"],["2013","ykShMtNgDB1","yz7jPBCDXlX","333337.0"],["2013","Yut5amdi7iw","Fez1Dp8bXSk","97497.0"],["2014","ykShMtNgDB1","YtVMnut7Foe","1788316.0"],["2013","ykShMtNgDB1","DTc1rxSmlde","316551.0"],["2013","Yut5amdi7iw","rrHtwyYjprs","200415.0"],["2013","Yut5amdi7iw","zfwo4rq1XC3","31699.0"],["2013","Yut5amdi7iw","NzvekEmEzUG","21013.0"],["2014","ykShMtNgDB1","Nc1C12TG69d","240554.0"],["2013","ykShMtNgDB1","zfwo4rq1XC3","436136.0"],["2014","ykShMtNgDB1","ZszYGa2Vnyc","93041.0"],["2013","Yut5amdi7iw","et6lWc8GDHy","7536.0"],["2013","ykShMtNgDB1","H2LvCkw2bCO","209008.0"],["2014","ykShMtNgDB1","PHGm198Hcil","110929.0"],["2014","ykShMtNgDB1","m2ux1UEElNB","420308.0"],["2013","Yut5amdi7iw","LoPF5WqswyW","20048.0"],["2014","Yut5amdi7iw","Qp6ocX9ESSa","74974.0"],["2014","Yut5amdi7iw","Qyg5jjxGeQD","139585.0"],["2013","Yut5amdi7iw","L9scGbK6d61","21483.0"],["2013","ykShMtNgDB1","bN5q5k5DgLA","1286194.0"],["2013","ykShMtNgDB1","m2ux1UEElNB","408293.0"],["2013","Yut5amdi7iw","vo788oc0NEn","61891.0"],["2013","Yut5amdi7iw","TO89Eu9qoSX","5800.0"],["2013","ykShMtNgDB1","yyW17iCz9As","1123107.0"],["2014","ykShMtNgDB1","Le7ysFRJrMk","278244.0"],["2013","Yut5amdi7iw","Hob4dzCAW2W","42665.0"],["2014","Yut5amdi7iw","saOGTLvMX4F","144551.0"],["2013","ykShMtNgDB1","Ak1TMj0oYc7","226349.0"],["2014","Yut5amdi7iw","VdIZ0pAYfBK","141783.0"],["2014","Yut5amdi7iw","N5FKtARi6dB","39047.0"],["2014","ykShMtNgDB1","bKA4yc2NUxA","200373.0"],["2013","ykShMtNgDB1","QBC1po2JaJW","247422.0"],["2013","Yut5amdi7iw","dIiTyLaZAEb","29651.0"],["2014","Yut5amdi7iw","aQEZnk4RzKv","47411.0"],["2014","ykShMtNgDB1","vYT08q7Wo33","1833416.0"],["2014","ykShMtNgDB1","DWSo42hunXH","600716.0"],["2013","ykShMtNgDB1","saOGTLvMX4F","636590.0"],["2013","Yut5amdi7iw","uPphu8kRXoZ","295261.0"],["2014","Yut5amdi7iw","cnsiTXSJqqF","76820.0"],["2014","Yut5amdi7iw","xOJxkz079Ek","161394.0"],["2013","ykShMtNgDB1","ZYYX8Q9SGoV","1406109.0"],["2014","Yut5amdi7iw","Le7ysFRJrMk","134805.0"],["2013","Yut5amdi7iw","xVzeWrXHf81","4597.0"],["2013","Yut5amdi7iw","Y8sOGpb4AFE","30721.0"],["2013","ykShMtNgDB1","OOplITY83ud","132265.0"],["2013","Yut5amdi7iw","qarQhOt2OEh","101149.0"],["2014","Yut5amdi7iw","plSLZJGUHZb","69749.0"],["2014","ykShMtNgDB1","lnOyHhoLzre","1700203.0"],["2013","Yut5amdi7iw","jAI2fd8kK1z","15930.0"],["2014","Yut5amdi7iw","dIiTyLaZAEb","119139.0"],["2014","Yut5amdi7iw","WgQHWeMx6Zl","77608.0"],["2014","Yut5amdi7iw","rQS2cX4JH88","56227.0"],["2014","Yut5amdi7iw","MiLb81EwC7j","195186.0"],["2013","ykShMtNgDB1","dFCrIa5paz7","279310.0"],["2013","Yut5amdi7iw","gncV3iPt6Sk","234485.0"],["2014","ykShMtNgDB1","rQS2cX4JH88","56454.0"],["2014","Yut5amdi7iw","PEIzWSzWQ7S","15243.0"],["2014","ykShMtNgDB1","NzvekEmEzUG","98835.0"],["2013","ykShMtNgDB1","NzVLQOcSJJU","247634.0"],["2014","ykShMtNgDB1","iEIdCVxSJct","299186.0"],["2013","Yut5amdi7iw","DTc1rxSmlde","165932.0"],["2013","Yut5amdi7iw","ilY7TEjviqa","5266.0"],["2014","Yut5amdi7iw","ts6eEeUjcfO","1530252.0"],["2014","Yut5amdi7iw","yyW17iCz9As","1037376.0"],["2014","Yut5amdi7iw","PHWaJvzTmL8","63257.0"],["2014","ykShMtNgDB1","gu92DYtO3ii","174756.0"],["2013","Yut5amdi7iw","LdzOZ9hNTwH","18520.0"],["2014","ykShMtNgDB1","Srvx9L1LGZM","154123.0"],["2013","ykShMtNgDB1","N8oGVhuoUcK","71770.0"],["2014","ykShMtNgDB1","IfQ2Sjbfdme","218482.0"],["2013","ykShMtNgDB1","A3b5mw8DJYC","2781510.0"],["2013","Yut5amdi7iw","IZAkMaffRh8","50670.0"],["2014","Yut5amdi7iw","Crkg9BoUo5w","860036.0"],["2013","ykShMtNgDB1","BVBmQDCexxG","319689.0"],["2014","ykShMtNgDB1","K8HUKJUZ7aj","204292.0"],["2014","ykShMtNgDB1","PvqxGEssig9","154522.0"],["2014","ykShMtNgDB1","F8NIzb16wVU","216025.0"],["2013","ykShMtNgDB1","kISvf8gGZMm","278783.0"],["2013","Yut5amdi7iw","qg5ySBw9X5l","267701.0"],["2014","Yut5amdi7iw","GOmwoDIGL98","33967.0"],["2014","ykShMtNgDB1","WCTbfnMiNF3","279696.0"],["2013","ykShMtNgDB1","tNFOa31xGhu","241778.0"],["2013","Yut5amdi7iw","D21VsjNL2LB","46195.0"],["2014","ykShMtNgDB1","aouUIozrc7I","471105.0"],["2014","Yut5amdi7iw","dPzNEI2Cxqj","109419.0"],["2013","Yut5amdi7iw","oMao5qA3DBy","21441.0"],["2014","ykShMtNgDB1","XLrownkhsKI","340528.0"],["2013","Yut5amdi7iw","RHLUbsrsFoE","20432.0"],["2014","Yut5amdi7iw","QE0OH5162nV","44164.0"],["2014","Yut5amdi7iw","OHu1VHzyA0x","95213.0"],["2013","Yut5amdi7iw","T3A9X81ABG3","8469.0"],["2013","Yut5amdi7iw","N5FKtARi6dB","21622.0"],["2013","Yut5amdi7iw","saOGTLvMX4F","16282.0"],["2014","ykShMtNgDB1","PEIzWSzWQ7S","416847.0"],["2014","ykShMtNgDB1","PM74xoecSpJ","137035.0"],["2013","ykShMtNgDB1","yPCs2xE66we","260520.0"],["2014","Yut5amdi7iw","f7UPzYMgzVH","381266.0"],["2014","Yut5amdi7iw","YtVMnut7Foe","1036018.0"],["2014","Yut5amdi7iw","tNFOa31xGhu","178772.0"],["2013","ykShMtNgDB1","PEIzWSzWQ7S","404932.0"],["2014","Yut5amdi7iw","mOqc3ajETpA","22904.0"],["2013","ykShMtNgDB1","lQOxGNRaklm","392958.0"],["2013","Yut5amdi7iw","ySuyuvNNFp8","96150.0"],["2013","Yut5amdi7iw","L5AfyN2zxns","44226.0"],["2013","ykShMtNgDB1","IGSrsG5I54W","683227.0"],["2014","Yut5amdi7iw","jAI2fd8kK1z","100092.0"],["2014","ykShMtNgDB1","AiyppObGUqI","252598.0"],["2013","Yut5amdi7iw","Sj50oz9EHvD","312309.0"],["2014","ykShMtNgDB1","mbXn83McbCh","356739.0"],["2013","ykShMtNgDB1","tLzrq5IZ23W","103936.0"],["2013","Yut5amdi7iw","dWfRpHKykpk","40677.0"],["2014","ykShMtNgDB1","Sj50oz9EHvD","2327576.0"],["2013","ykShMtNgDB1","d07Wtk7brGz","302433.0"],["2014","ykShMtNgDB1","jAI2fd8kK1z","373349.0"],["2013","Yut5amdi7iw","Cpd5l15XxwA","1128107.0"],["2013","Yut5amdi7iw","aouUIozrc7I","34721.0"],["2014","ykShMtNgDB1","MAL4cfZoFhJ","3555381.0"],["2014","Yut5amdi7iw","B9idcF4fOIW","63350.0"],["2014","ykShMtNgDB1","GI57B0uNPOX","48528.0"],["2013","ykShMtNgDB1","GbVBjR8A7aK","448820.0"],["2013","ykShMtNgDB1","uHp3aLKA6Tn","193125.0"],["2013","Yut5amdi7iw","AiyppObGUqI","131835.0"],["2014","Yut5amdi7iw","uHp3aLKA6Tn","235274.0"],["2013","ykShMtNgDB1","ZszYGa2Vnyc","92207.0"],["2014","ykShMtNgDB1","tLzrq5IZ23W","105191.0"],["2014","ykShMtNgDB1","sjKfO239rjD","80273.0"],["2014","ykShMtNgDB1","btLScg6XCBN","206055.0"],["2013","ykShMtNgDB1","G2obPNftMUt","293200.0"],["2013","Yut5amdi7iw","F8NIzb16wVU","7734.0"],["2014","ykShMtNgDB1","A54bflEH57w","190121.0"],["2013","Yut5amdi7iw","QBC1po2JaJW","14228.0"],["2013","Yut5amdi7iw","K8HUKJUZ7aj","3612.0"],["2013","Yut5amdi7iw","XLrownkhsKI","16408.0"],["2013","Yut5amdi7iw","yiR1QdOwPqP","275289.0"],["2013","Yut5amdi7iw","GbVBjR8A7aK","75653.0"],["2014","Yut5amdi7iw","D21VsjNL2LB","99620.0"],["2013","Yut5amdi7iw","ppnbxB0TxjG","35324.0"],["2013","ykShMtNgDB1","OzGGHqXQn5p","419678.0"],["2014","Yut5amdi7iw","RD96nI1JXVV","646869.0"],["2013","Yut5amdi7iw","QeMjl7Ld0Vj","30186.0"],["2013","Yut5amdi7iw","dt0Q0NhyPty","21065.0"],["2013","ykShMtNgDB1","OHu1VHzyA0x","133829.0"],["2014","Yut5amdi7iw","z4dfv9EOq3c","79689.0"],["2014","ykShMtNgDB1","TO89Eu9qoSX","152428.0"],["2014","ykShMtNgDB1","xRx7W86ElUH","293643.0"],["2014","ykShMtNgDB1","kISvf8gGZMm","284698.0"],["2013","ykShMtNgDB1","VMTJLxcFH9o","475213.0"],["2014","Yut5amdi7iw","O8O3HQdJWHX","87007.0"],["2014","Yut5amdi7iw","vQvBfxn7Cjs","70227.0"],["2013","Yut5amdi7iw","OHu1VHzyA0x","19296.0"],["2014","ykShMtNgDB1","X5MzEu84hUN","230252.0"],["2013","ykShMtNgDB1","LGTVRhKSn1V","1402527.0"],["2014","ykShMtNgDB1","EO3Ps3ny0Nr","1600644.0"],["2014","ykShMtNgDB1","O8O3HQdJWHX","431647.0"],["2014","ykShMtNgDB1","z4dfv9EOq3c","221274.0"],["2013","Yut5amdi7iw","lgZ6HfZaj3f","305109.0"],["2013","Yut5amdi7iw","Q16E1rzDnVD","56059.0"],["2013","Yut5amdi7iw","bDteRg6tH0A","55926.0"],["2014","Yut5amdi7iw","aouUIozrc7I","164156.0"],["2014","ykShMtNgDB1","Cpd5l15XxwA","2172961.0"],["2013","ykShMtNgDB1","ts6eEeUjcfO","1877287.0"],["2013","ykShMtNgDB1","AiyppObGUqI","247349.0"],["2013","ykShMtNgDB1","L5AfyN2zxns","321907.0"],["2013","Yut5amdi7iw","RD96nI1JXVV","240462.0"],["2014","ykShMtNgDB1","dPzNEI2Cxqj","254166.0"],["2014","ykShMtNgDB1","QBC1po2JaJW","252927.0"],["2014","Yut5amdi7iw","lgZ6HfZaj3f","527162.0"],["2013","ykShMtNgDB1","IgTAEKMqKRe","1612930.0"],["2014","ykShMtNgDB1","jupsOTyKi1W","109482.0"],["2013","ykShMtNgDB1","RCDM6DotMZw","199030.0"],["2013","ykShMtNgDB1","D21VsjNL2LB","163278.0"],["2013","ykShMtNgDB1","DWSo42hunXH","581800.0"],["2014","ykShMtNgDB1","tcZz4Bh4mqc","259683.0"],["2013","ykShMtNgDB1","GI57B0uNPOX","47472.0"],["2013","ykShMtNgDB1","acZHYslyJLt","4615928.0"],["2013","Yut5amdi7iw","lnOyHhoLzre","158614.0"],["2013","Yut5amdi7iw","Srvx9L1LGZM","106361.0"],["2013","ykShMtNgDB1","yh0b4OAgg8z","197700.0"],["2014","ykShMtNgDB1","IGSrsG5I54W","704034.0"],["2014","Yut5amdi7iw","vAtZ8a924Lx","383655.0"],["2014","ykShMtNgDB1","aMnC7MINXlM","120576.0"],["2014","ykShMtNgDB1","N8oGVhuoUcK","73366.0"],["2014","Yut5amdi7iw","cb9rqgLXFeh","37749.0"],["2013","Yut5amdi7iw","IfQ2Sjbfdme","27165.0"],["2013","ykShMtNgDB1","rrHtwyYjprs","250986.0"],["2013","ykShMtNgDB1","EO3Ps3ny0Nr","1567382.0"],["2014","Yut5amdi7iw","fogigwn9cW7","86603.0"],["2013","Yut5amdi7iw","btLScg6XCBN","27551.0"],["2014","Yut5amdi7iw","wIjscdPZF3N","156240.0"],["2014","Yut5amdi7iw","G9VxK1Dmkpc","33494.0"],["2014","ykShMtNgDB1","P5H056daq2I","318142.0"],["2014","Yut5amdi7iw","PvqxGEssig9","98567.0"],["2014","Yut5amdi7iw","dFCrIa5paz7","41401.0"],["2013","ykShMtNgDB1","Sj50oz9EHvD","2272380.0"],["2014","ykShMtNgDB1","YFPElmUhUok","353256.0"],["2014","ykShMtNgDB1","WAwWjYYzdkS","532244.0"],["2014","ykShMtNgDB1","DkxlFk8MuM7","371703.0"],["2013","ykShMtNgDB1","O8O3HQdJWHX","418889.0"],["2014","Yut5amdi7iw","vU0Qt1A5IDz","933812.0"],["2013","ykShMtNgDB1","aa5sxEFiAwN","134288.0"],["2014","Yut5amdi7iw","aVLidCZ2RYk","75761.0"],["2013","ykShMtNgDB1","Q16E1rzDnVD","267315.0"],["2013","Yut5amdi7iw","m4ow47nd3DC","11750.0"],["2013","ykShMtNgDB1","PF4defRibDi","164817.0"],["2014","Yut5amdi7iw","ppnbxB0TxjG","71672.0"],["2014","Yut5amdi7iw","dt0Q0NhyPty","88145.0"],["2014","Yut5amdi7iw","XL0luikY9oG","57645.0"],["2014","Yut5amdi7iw","P5H056daq2I","169909.0"],["2014","ykShMtNgDB1","yTTjcYh4xqa","281271.0"],["2013","ykShMtNgDB1","et6lWc8GDHy","353446.0"],["2014","Yut5amdi7iw","xVzeWrXHf81","48985.0"],["2014","ykShMtNgDB1","vAtZ8a924Lx","847808.0"],["2013","ykShMtNgDB1","XL0luikY9oG","205919.0"],["2013","ykShMtNgDB1","SnczTnCrk6d","103859.0"],["2014","Yut5amdi7iw","fSZfOuCkmAb","24734.0"],["2013","ykShMtNgDB1","dt0Q0NhyPty","216705.0"],["2013","ykShMtNgDB1","Crkg9BoUo5w","2530319.0"],["2013","ykShMtNgDB1","iEIdCVxSJct","289763.0"],["2013","ykShMtNgDB1","dIiTyLaZAEb","220691.0"],["2014","ykShMtNgDB1","PF4defRibDi","168315.0"],["2013","ykShMtNgDB1","RHLUbsrsFoE","230768.0"],["2014","ykShMtNgDB1","nUFAmN93pH4","331395.0"],["2013","ykShMtNgDB1","PHGm198Hcil","109606.0"],["2013","Yut5amdi7iw","B9idcF4fOIW","15848.0"],["2014","ykShMtNgDB1","Crkg9BoUo5w","2613035.0"],["2014","ykShMtNgDB1","gOcZSwBmijY","233040.0"],["2014","Yut5amdi7iw","zHa2ohFrpPM","42589.0"],["2014","ykShMtNgDB1","bRz3nu8rSWS","277549.0"],["2013","ykShMtNgDB1","LbM25p7KBDP","177509.0"],["2013","ykShMtNgDB1","PM74xoecSpJ","132717.0"],["2014","ykShMtNgDB1","WgQHWeMx6Zl","284770.0"],["2014","ykShMtNgDB1","PHWaJvzTmL8","183948.0"],["2013","ykShMtNgDB1","Le7ysFRJrMk","271645.0"],["2014","ykShMtNgDB1","xVzeWrXHf81","103811.0"],["2014","Yut5amdi7iw","aa5sxEFiAwN","46374.0"],["2013","ykShMtNgDB1","vU0Qt1A5IDz","2090695.0"],["2013","Yut5amdi7iw","LbM25p7KBDP","54172.0"],["2013","Yut5amdi7iw","QKEr8DFutO8","137839.0"],["2014","ykShMtNgDB1","lgZ6HfZaj3f","439550.0"],["2014","Yut5amdi7iw","uPphu8kRXoZ","256436.0"],["2014","Yut5amdi7iw","WAwWjYYzdkS","166331.0"],["2014","ykShMtNgDB1","I58Bh8dN2sO","211058.0"],["2014","Yut5amdi7iw","Cpd5l15XxwA","1040358.0"],["2014","Yut5amdi7iw","OzGGHqXQn5p","241945.0"],["2014","Yut5amdi7iw","et6lWc8GDHy","16058.0"],["2013","Yut5amdi7iw","H2LvCkw2bCO","39894.0"],["2014","Yut5amdi7iw","ZYYX8Q9SGoV","570959.0"],["2013","ykShMtNgDB1","gu92DYtO3ii","170953.0"],["2013","ykShMtNgDB1","A54bflEH57w","184135.0"],["2013","ykShMtNgDB1","P5H056daq2I","311531.0"],["2013","Yut5amdi7iw","acZHYslyJLt","3801257.0"],["2013","ykShMtNgDB1","dGtH1WiNUrP","192469.0"],["2013","ykShMtNgDB1","K8HUKJUZ7aj","198454.0"],["2014","Yut5amdi7iw","vo788oc0NEn","96190.0"],["2014","ykShMtNgDB1","T3A9X81ABG3","175795.0"],["2014","Yut5amdi7iw","F8NIzb16wVU","61238.0"],["2013","ykShMtNgDB1","QE0OH5162nV","355659.0"],["2013","Yut5amdi7iw","Nc1C12TG69d","51128.0"],["2013","Yut5amdi7iw","N8oGVhuoUcK","106172.0"],["2014","ykShMtNgDB1","hAFRrgDK0fy","2943951.0"],["2013","Yut5amdi7iw","bRz3nu8rSWS","15611.0"],["2014","ykShMtNgDB1","SnczTnCrk6d","106170.0"],["2013","Yut5amdi7iw","PEIzWSzWQ7S","8232.0"],["2014","Yut5amdi7iw","yiR1QdOwPqP","243748.0"],["2014","Yut5amdi7iw","N8oGVhuoUcK","114609.0"],["2013","Yut5amdi7iw","vAtZ8a924Lx","94240.0"],["2014","ykShMtNgDB1","uPphu8kRXoZ","325764.0"],["2013","Yut5amdi7iw","aQEZnk4RzKv","21855.0"],["2014","ykShMtNgDB1","V60DkMrlQ5Q","157458.0"],["2013","Yut5amdi7iw","nUFAmN93pH4","134892.0"],["2013","Yut5amdi7iw","qHJkyM0bG8U","7279.0"],["2014","ykShMtNgDB1","IZAkMaffRh8","384615.0"],["2014","ykShMtNgDB1","XL0luikY9oG","210289.0"],["2014","ykShMtNgDB1","IYqT1Xik8Bj","210483.0"],["2014","ykShMtNgDB1","aa5sxEFiAwN","135366.0"],["2014","ykShMtNgDB1","LdzOZ9hNTwH","338914.0"],["2014","Yut5amdi7iw","vYT08q7Wo33","746627.0"],["2014","ykShMtNgDB1","r9NgS2Jsu9I","311072.0"],["2013","Yut5amdi7iw","GI57B0uNPOX","75528.0"],["2013","Yut5amdi7iw","kISvf8gGZMm","154491.0"],["2014","ykShMtNgDB1","N5FKtARi6dB","322260.0"],["2013","ykShMtNgDB1","F8NIzb16wVU","208803.0"],["2014","Yut5amdi7iw","C96DDKK03pu","126309.0"],["2013","Yut5amdi7iw","ZszYGa2Vnyc","89189.0"],["2014","ykShMtNgDB1","cjlkhW8VMDO","151824.0"],["2013","Yut5amdi7iw","yTTjcYh4xqa","80316.0"],["2013","ykShMtNgDB1","DkxlFk8MuM7","363615.0"],["2013","ykShMtNgDB1","VdIZ0pAYfBK","207624.0"],["2013","Yut5amdi7iw","cnsiTXSJqqF","22677.0"],["2014","Yut5amdi7iw","WB7EAwS3F8N","45324.0"],["2013","ykShMtNgDB1","Hob4dzCAW2W","265703.0"],["2013","ykShMtNgDB1","dWfRpHKykpk","227555.0"],["2014","Yut5amdi7iw","MAL4cfZoFhJ","465122.0"],["2013","Yut5amdi7iw","Qp6ocX9ESSa","21896.0"],["2014","ykShMtNgDB1","yPCs2xE66we","266849.0"],["2014","Yut5amdi7iw","Y8sOGpb4AFE","92476.0"],["2013","ykShMtNgDB1","cjlkhW8VMDO","147043.0"],["2014","Yut5amdi7iw","mKI72g04l0D","23507.0"],["2014","Yut5amdi7iw","sjKfO239rjD","138294.0"],["2014","ykShMtNgDB1","ts6eEeUjcfO","1775049.0"],["2013","Yut5amdi7iw","bKA4yc2NUxA","40445.0"],["2014","ykShMtNgDB1","D21VsjNL2LB","167746.0"],["2014","ykShMtNgDB1","Qp6ocX9ESSa","134743.0"],["2013","ykShMtNgDB1","Srvx9L1LGZM","227880.0"],["2014","Yut5amdi7iw","LGTVRhKSn1V","705241.0"],["2014","Yut5amdi7iw","TO89Eu9qoSX","9042.0"],["2013","ykShMtNgDB1","W884lMlfpca","180078.0"],["2013","ykShMtNgDB1","qHJkyM0bG8U","69827.0"],["2013","Yut5amdi7iw","LGTVRhKSn1V","458133.0"],["2013","Yut5amdi7iw","Yb483pDzzWj","62911.0"],["2013","Yut5amdi7iw","QUTWca9YxNb","31878.0"],["2013","Yut5amdi7iw","rQS2cX4JH88","7467.0"],["2014","ykShMtNgDB1","yyW17iCz9As","1069265.0"],["2014","ykShMtNgDB1","PKl52zU7vuH","148816.0"],["2013","ykShMtNgDB1","vJY7WRfb5Hc","305060.0"],["2013","ykShMtNgDB1","dPzNEI2Cxqj","247393.0"],["2014","Yut5amdi7iw","DWSo42hunXH","164644.0"],["2014","ykShMtNgDB1","QE0OH5162nV","366491.0"],["2014","ykShMtNgDB1","RCDM6DotMZw","204272.0"],["2014","Yut5amdi7iw","dWfRpHKykpk","130463.0"],["2014","ykShMtNgDB1","LGTVRhKSn1V","1435159.0"],["2014","ykShMtNgDB1","AvfNRAIsvhg","317192.0"],["2014","Yut5amdi7iw","A3b5mw8DJYC","966746.0"],["2013","Yut5amdi7iw","mKI72g04l0D","9613.0"],["2013","Yut5amdi7iw","FylvwNXCTAQ","149491.0"],["2013","ykShMtNgDB1","lnOyHhoLzre","1669871.0"],["2013","Yut5amdi7iw","NzVLQOcSJJU","10122.0"],["2013","ykShMtNgDB1","f7UPzYMgzVH","374520.0"],["2013","Yut5amdi7iw","xBWOfftpkLT","57136.0"],["2013","ykShMtNgDB1","duES2Gfgvpw","267679.0"],["2013","Yut5amdi7iw","WAwWjYYzdkS","37086.0"],["2014","Yut5amdi7iw","LbM25p7KBDP","96041.0"],["2013","ykShMtNgDB1","L9scGbK6d61","298427.0"],["2013","Yut5amdi7iw","G9VxK1Dmkpc","7088.0"],["2014","ykShMtNgDB1","NzVLQOcSJJU","253903.0"],["2013","ykShMtNgDB1","tcZz4Bh4mqc","256841.0"],["2013","ykShMtNgDB1","G9VxK1Dmkpc","152228.0"],["2014","Yut5amdi7iw","nUFAmN93pH4","203632.0"],["2014","ykShMtNgDB1","L9scGbK6d61","306593.0"],["2013","ykShMtNgDB1","gncV3iPt6Sk","222106.0"],["2014","Yut5amdi7iw","IYqT1Xik8Bj","106678.0"],["2014","ykShMtNgDB1","QKEr8DFutO8","242934.0"],["2014","Yut5amdi7iw","vJY7WRfb5Hc","95109.0"],["2013","ykShMtNgDB1","lgZ6HfZaj3f","427840.0"],["2014","Yut5amdi7iw","IGSrsG5I54W","75813.0"],["2014","Yut5amdi7iw","mbXn83McbCh","102423.0"],["2013","Yut5amdi7iw","EO3Ps3ny0Nr","774102.0"],["2014","ykShMtNgDB1","Kug5uWxs0mu","318295.0"],["2013","Yut5amdi7iw","VMgrQWSVIYn","699808.0"],["2014","Yut5amdi7iw","uafqZbOYpVL","167725.0"],["2014","Yut5amdi7iw","cjlkhW8VMDO","33437.0"],["2013","Yut5amdi7iw","f7UPzYMgzVH","62432.0"],["2014","ykShMtNgDB1","tNFOa31xGhu","247404.0"],["2013","Yut5amdi7iw","r9NgS2Jsu9I","95826.0"],["2013","Yut5amdi7iw","ouZ5YpZ4T3a","39240.0"],["2014","Yut5amdi7iw","GI57B0uNPOX","67231.0"],["2013","ykShMtNgDB1","MiLb81EwC7j","214356.0"],["2013","Yut5amdi7iw","IgTAEKMqKRe","442071.0"],["2013","ykShMtNgDB1","cZMveFzVrXh","216183.0"],["2013","Yut5amdi7iw","PHWaJvzTmL8","18608.0"],["2013","Yut5amdi7iw","WCTbfnMiNF3","15049.0"],["2013","ykShMtNgDB1","sjKfO239rjD","79554.0"],["2014","Yut5amdi7iw","PM74xoecSpJ","196962.0"],["2014","ykShMtNgDB1","zfwo4rq1XC3","446730.0"],["2014","Yut5amdi7iw","GbVBjR8A7aK","179283.0"],["2014","ykShMtNgDB1","d07Wtk7brGz","310710.0"],["2014","Yut5amdi7iw","EO3Ps3ny0Nr","783602.0"],["2014","ykShMtNgDB1","FylvwNXCTAQ","348762.0"],["2013","ykShMtNgDB1","Qp6ocX9ESSa","131417.0"],["2014","ykShMtNgDB1","BVBmQDCexxG","327455.0"],["2014","ykShMtNgDB1","gncV3iPt6Sk","227047.0"],["2013","Yut5amdi7iw","z4dfv9EOq3c","22756.0"],["2013","Yut5amdi7iw","X5MzEu84hUN","32828.0"],["2014","Yut5amdi7iw","OOplITY83ud","105324.0"],["2014","Yut5amdi7iw","aiZstwpkrny","92255.0"],["2014","ykShMtNgDB1","xe93MrFXOYV","1365268.0"],["2014","ykShMtNgDB1","RHLUbsrsFoE","236137.0"],["2013","Yut5amdi7iw","xOJxkz079Ek","126847.0"],["2014","Yut5amdi7iw","QKEr8DFutO8","88254.0"],["2013","Yut5amdi7iw","I58Bh8dN2sO","6016.0"],["2014","ykShMtNgDB1","uafqZbOYpVL","283024.0"],["2014","Yut5amdi7iw","ZszYGa2Vnyc","74044.0"],["2013","Yut5amdi7iw","uafqZbOYpVL","178316.0"],["2014","ykShMtNgDB1","vU0Qt1A5IDz","2137202.0"],["2013","Yut5amdi7iw","plSLZJGUHZb","81453.0"],["2014","ykShMtNgDB1","qHJkyM0bG8U","71380.0"],["2014","Yut5amdi7iw","bDteRg6tH0A","63416.0"],["2014","Yut5amdi7iw","HIOQoi1aeL8","1032782.0"],["2013","Yut5amdi7iw","Crkg9BoUo5w","462672.0"],["2013","ykShMtNgDB1","bDteRg6tH0A","319602.0"],["2013","ykShMtNgDB1","bRz3nu8rSWS","270697.0"],["2013","Yut5amdi7iw","MAL4cfZoFhJ","205534.0"],["2014","Yut5amdi7iw","BVBmQDCexxG","180044.0"],["2013","Yut5amdi7iw","XL0luikY9oG","18163.0"],["2013","Yut5amdi7iw","DkxlFk8MuM7","38788.0"],["2013","ykShMtNgDB1","I58Bh8dN2sO","207294.0"],["2014","ykShMtNgDB1","DTc1rxSmlde","323268.0"],["2014","ykShMtNgDB1","RD96nI1JXVV","2232558.0"],["2013","ykShMtNgDB1","m4ow47nd3DC","163116.0"],["2013","ykShMtNgDB1","GOmwoDIGL98","86434.0"],["2014","Yut5amdi7iw","hAFRrgDK0fy","782514.0"],["2014","Yut5amdi7iw","AiyppObGUqI","161760.0"],["2014","Yut5amdi7iw","cZMveFzVrXh","151883.0"],["2013","Yut5amdi7iw","xe93MrFXOYV","1452424.0"],["2014","ykShMtNgDB1","aiZstwpkrny","197669.0"],["2013","ykShMtNgDB1","QKEr8DFutO8","236465.0"],["2014","Yut5amdi7iw","iEIdCVxSJct","90470.0"],["2013","ykShMtNgDB1","fogigwn9cW7","411488.0"],["2013","Yut5amdi7iw","Kug5uWxs0mu","20456.0"],["2013","ykShMtNgDB1","btLScg6XCBN","200968.0"],["2014","ykShMtNgDB1","Ak1TMj0oYc7","231152.0"],["2013","Yut5amdi7iw","gu92DYtO3ii","6013.0"],["2013","ykShMtNgDB1","YtVMnut7Foe","1740678.0"],["2013","ykShMtNgDB1","vQvBfxn7Cjs","256067.0"],["2014","Yut5amdi7iw","Kug5uWxs0mu","78114.0"],["2014","Yut5amdi7iw","yh0b4OAgg8z","17347.0"],["2014","ykShMtNgDB1","QekURU8eIU0","134267.0"],["2013","Yut5amdi7iw","AvfNRAIsvhg","10287.0"],["2013","ykShMtNgDB1","PvqxGEssig9","152678.0"],["2013","ykShMtNgDB1","xVzeWrXHf81","101047.0"],["2013","Yut5amdi7iw","G2obPNftMUt","36121.0"],["2013","Yut5amdi7iw","OOplITY83ud","101192.0"],["2014","Yut5amdi7iw","tLzrq5IZ23W","119139.0"],["2014","Yut5amdi7iw","xe93MrFXOYV","1355276.0"],["2014","Yut5amdi7iw","A54bflEH57w","81350.0"],["2014","ykShMtNgDB1","Fez1Dp8bXSk","245822.0"],["2013","ykShMtNgDB1","T3A9X81ABG3","171626.0"],["2014","Yut5amdi7iw","Hob4dzCAW2W","83077.0"],["2014","ykShMtNgDB1","wsCWwNbLJNY","124481.0"],["2014","Yut5amdi7iw","cirtJ7KuNU0","6387.0"],["2014","ykShMtNgDB1","vJY7WRfb5Hc","310601.0"],["2014","ykShMtNgDB1","WB7EAwS3F8N","368853.0"],["2014","ykShMtNgDB1","sWOWPBvwNY2","962179.0"],["2014","ykShMtNgDB1","OHu1VHzyA0x","136260.0"],["2013","Yut5amdi7iw","ts6eEeUjcfO","1376701.0"],["2014","Yut5amdi7iw","QBC1po2JaJW","117965.0"],["2014","ykShMtNgDB1","HIOQoi1aeL8","1531110.0"],["2014","ykShMtNgDB1","oMao5qA3DBy","427937.0"],["2014","Yut5amdi7iw","QeMjl7Ld0Vj","103553.0"],["2013","Yut5amdi7iw","yyW17iCz9As","1128204.0"],["2014","Yut5amdi7iw","qHJkyM0bG8U","58781.0"],["2014","Yut5amdi7iw","qg5ySBw9X5l","381281.0"],["2014","ykShMtNgDB1","ZYYX8Q9SGoV","1435949.0"],["2013","Yut5amdi7iw","dGtH1WiNUrP","157069.0"],["2013","Yut5amdi7iw","lQOxGNRaklm","24631.0"],["2014","ykShMtNgDB1","dWfRpHKykpk","233784.0"],["2013","ykShMtNgDB1","XLrownkhsKI","329804.0"],["2014","Yut5amdi7iw","W884lMlfpca","111246.0"],["2013","Yut5amdi7iw","cZMveFzVrXh","44517.0"],["2014","ykShMtNgDB1","yh0b4OAgg8z","202501.0"],["2014","Yut5amdi7iw","Ak1TMj0oYc7","118667.0"],["2013","Yut5amdi7iw","duES2Gfgvpw","74666.0"],["2014","Yut5amdi7iw","ilY7TEjviqa","62084.0"],["2013","Yut5amdi7iw","YFPElmUhUok","29221.0"],["2013","ykShMtNgDB1","xRx7W86ElUH","284394.0"],["2013","Yut5amdi7iw","sjKfO239rjD","152159.0"],["2014","Yut5amdi7iw","DTc1rxSmlde","117061.0"],["2013","Yut5amdi7iw","BVBmQDCexxG","36496.0"],["2013","ykShMtNgDB1","vAtZ8a924Lx","1035131.0"],["2014","Yut5amdi7iw","d07Wtk7brGz","91862.0"],["2014","ykShMtNgDB1","Q16E1rzDnVD","272170.0"],["2014","ykShMtNgDB1","dIiTyLaZAEb","226051.0"],["2014","Yut5amdi7iw","jupsOTyKi1W","18250.0"],["2014","ykShMtNgDB1","GbVBjR8A7aK","459722.0"],["2014","ykShMtNgDB1","VdIZ0pAYfBK","212030.0"],["2013","ykShMtNgDB1","Kug5uWxs0mu","308889.0"],["2014","Yut5amdi7iw","gu92DYtO3ii","52470.0"],["2014","Yut5amdi7iw","PHGm198Hcil","88328.0"],["2014","ykShMtNgDB1","vQvBfxn7Cjs","261501.0"],["2014","ykShMtNgDB1","wIjscdPZF3N","574871.0"],["2013","ykShMtNgDB1","bKA4yc2NUxA","195426.0"],["2013","Yut5amdi7iw","A54bflEH57w","33929.0"],["2013","Yut5amdi7iw","vYT08q7Wo33","210449.0"],["2013","Yut5amdi7iw","C96DDKK03pu","59638.0"],["2014","ykShMtNgDB1","VMTJLxcFH9o","483845.0"],["2013","ykShMtNgDB1","IfQ2Sjbfdme","213303.0"],["2014","Yut5amdi7iw","bKA4yc2NUxA","116132.0"],["2013","ykShMtNgDB1","WAwWjYYzdkS","517030.0"],["2014","Yut5amdi7iw","AvfNRAIsvhg","57242.0"],["2014","ykShMtNgDB1","plSLZJGUHZb","236526.0"],["2013","ykShMtNgDB1","IZAkMaffRh8","374746.0"],["2013","Yut5amdi7iw","Ak1TMj0oYc7","122910.0"],["2013","ykShMtNgDB1","yiR1QdOwPqP","337558.0"],["2014","Yut5amdi7iw","tcZz4Bh4mqc","152551.0"],["2013","Yut5amdi7iw","fogigwn9cW7","19741.0"],["2014","Yut5amdi7iw","YFPElmUhUok","149675.0"],["2013","Yut5amdi7iw","cirtJ7KuNU0","7198.0"],["2014","ykShMtNgDB1","mKI72g04l0D","247487.0"],["2014","ykShMtNgDB1","ySuyuvNNFp8","285627.0"],["2014","Yut5amdi7iw","oMao5qA3DBy","94282.0"],["2013","Yut5amdi7iw","dPzNEI2Cxqj","43655.0"],["2013","Yut5amdi7iw","mOqc3ajETpA","4541.0"],["2013","ykShMtNgDB1","Fez1Dp8bXSk","240714.0"],["2013","Yut5amdi7iw","ZYYX8Q9SGoV","241925.0"],["2014","Yut5amdi7iw","Fez1Dp8bXSk","86844.0"],["2014","ykShMtNgDB1","IgTAEKMqKRe","1642222.0"],["2013","Yut5amdi7iw","tNFOa31xGhu","181864.0"],["2014","ykShMtNgDB1","bDteRg6tH0A","325405.0"],["2013","ykShMtNgDB1","fSZfOuCkmAb","192302.0"],["2013","Yut5amdi7iw","hAFRrgDK0fy","208604.0"],["2013","Yut5amdi7iw","VdIZ0pAYfBK","37173.0"],["2013","ykShMtNgDB1","qarQhOt2OEh","707735.0"],["2014","Yut5amdi7iw","Sj50oz9EHvD","875947.0"],["2013","ykShMtNgDB1","LdzOZ9hNTwH","328241.0"],["2014","ykShMtNgDB1","fogigwn9cW7","423596.0"],["2013","Yut5amdi7iw","wIjscdPZF3N","280388.0"],["2014","Yut5amdi7iw","kISvf8gGZMm","148599.0"],["2014","ykShMtNgDB1","C96DDKK03pu","340765.0"],["2013","Yut5amdi7iw","d07Wtk7brGz","24185.0"],["2014","ykShMtNgDB1","mOqc3ajETpA","190623.0"],["2014","Yut5amdi7iw","Srvx9L1LGZM","135338.0"],["2013","ykShMtNgDB1","nUFAmN93pH4","323538.0"],["2013","Yut5amdi7iw","P1TuGaaZ981","90186.0"],["2013","Yut5amdi7iw","tcZz4Bh4mqc","107391.0"],["2014","Yut5amdi7iw","ouZ5YpZ4T3a","126850.0"],["2014","Yut5amdi7iw","ySuyuvNNFp8","232814.0"],["2013","ykShMtNgDB1","IYqT1Xik8Bj","207973.0"],["2013","ykShMtNgDB1","uPphu8kRXoZ","318675.0"],["2013","ykShMtNgDB1","aiZstwpkrny","195899.0"],["2014","Yut5amdi7iw","e3ATlebHNrD","178289.0"],["2014","Yut5amdi7iw","DkxlFk8MuM7","126083.0"],["2014","Yut5amdi7iw","V60DkMrlQ5Q","55133.0"],["2013","ykShMtNgDB1","xBWOfftpkLT","220542.0"],["2013","Yut5amdi7iw","aVLidCZ2RYk","19721.0"],["2014","Yut5amdi7iw","NzvekEmEzUG","9818.0"],["2013","ykShMtNgDB1","aMnC7MINXlM","118425.0"],["2013","ykShMtNgDB1","hAFRrgDK0fy","2856946.0"],["2013","Yut5amdi7iw","PHGm198Hcil","101676.0"],["2013","Yut5amdi7iw","kZ6RlMnt2bp","134828.0"],["2013","ykShMtNgDB1","aouUIozrc7I","458556.0"],["2014","ykShMtNgDB1","vo788oc0NEn","154713.0"],["2013","ykShMtNgDB1","WgQHWeMx6Zl","278852.0"],["2014","Yut5amdi7iw","Q16E1rzDnVD","66641.0"],["2014","Yut5amdi7iw","QUTWca9YxNb","80622.0"],["2014","Yut5amdi7iw","X5MzEu84hUN","89100.0"],["2014","Yut5amdi7iw","LdzOZ9hNTwH","65666.0"],["2013","ykShMtNgDB1","MAL4cfZoFhJ","1785352.0"],["2014","ykShMtNgDB1","ouZ5YpZ4T3a","309267.0"],["2013","Yut5amdi7iw","HIOQoi1aeL8","972132.0"],["2014","ykShMtNgDB1","W884lMlfpca","181706.0"],["2013","Yut5amdi7iw","sWOWPBvwNY2","261742.0"],["2014","Yut5amdi7iw","wsCWwNbLJNY","51752.0"],["2014","ykShMtNgDB1","qarQhOt2OEh","713418.0"],["2014","Yut5amdi7iw","I58Bh8dN2sO","8880.0"],["2014","ykShMtNgDB1","cZMveFzVrXh","223215.0"],["2013","Yut5amdi7iw","MiLb81EwC7j","42993.0"],["2013","Yut5amdi7iw","QE0OH5162nV","10989.0"],["2014","Yut5amdi7iw","gOcZSwBmijY","114899.0"],["2013","ykShMtNgDB1","LoPF5WqswyW","298520.0"],["2014","ykShMtNgDB1","uHp3aLKA6Tn","197618.0"],["2014","Yut5amdi7iw","Yb483pDzzWj","87626.0"],["2013","ykShMtNgDB1","WCTbfnMiNF3","274706.0"],["2013","Yut5amdi7iw","WgQHWeMx6Zl","75362.0"],["2014","Yut5amdi7iw","QekURU8eIU0","135201.0"],["2013","ykShMtNgDB1","QekURU8eIU0","131345.0"],["2013","Yut5amdi7iw","bN5q5k5DgLA","873917.0"],["2013","ykShMtNgDB1","ySuyuvNNFp8","279412.0"],["2013","ykShMtNgDB1","YFPElmUhUok","342132.0"],["2013","Yut5amdi7iw","aMnC7MINXlM","3198.0"],["2014","Yut5amdi7iw","yTTjcYh4xqa","62184.0"],["2014","ykShMtNgDB1","G2obPNftMUt","300322.0"],["2013","Yut5amdi7iw","jupsOTyKi1W","1029.0"],["2014","Yut5amdi7iw","G2obPNftMUt","66554.0"],["2014","Yut5amdi7iw","RCDM6DotMZw","53930.0"],["2014","Yut5amdi7iw","L9scGbK6d61","95531.0"],["2014","ykShMtNgDB1","dt0Q0NhyPty","221969.0"],["2013","ykShMtNgDB1","cb9rqgLXFeh","315160.0"],["2014","ykShMtNgDB1","xBWOfftpkLT","222983.0"],["2014","ykShMtNgDB1","QUTWca9YxNb","132324.0"],["2013","Yut5amdi7iw","PM74xoecSpJ","64163.0"],["2014","Yut5amdi7iw","IfQ2Sjbfdme","82625.0"],["2014","ykShMtNgDB1","L5AfyN2zxns","332373.0"],["2014","ykShMtNgDB1","dGtH1WiNUrP","194209.0"],["2013","ykShMtNgDB1","xe93MrFXOYV","1290915.0"],["2013","ykShMtNgDB1","gOcZSwBmijY","230260.0"],["2014","ykShMtNgDB1","zHa2ohFrpPM","341129.0"],["2014","ykShMtNgDB1","duES2Gfgvpw","274180.0"],["2014","Yut5amdi7iw","r9NgS2Jsu9I","221124.0"],["2013","ykShMtNgDB1","r9NgS2Jsu9I","304608.0"],["2013","Yut5amdi7iw","W884lMlfpca","110457.0"],["2014","Yut5amdi7iw","VMTJLxcFH9o","37636.0"],["2014","ykShMtNgDB1","OOplITY83ud","133461.0"],["2013","ykShMtNgDB1","Yb483pDzzWj","163283.0"],["2013","ykShMtNgDB1","kZ6RlMnt2bp","2359050.0"],["2013","Yut5amdi7iw","PKl52zU7vuH","6415.0"],["2014","Yut5amdi7iw","m4ow47nd3DC","23376.0"],["2014","ykShMtNgDB1","H2LvCkw2bCO","213657.0"],["2013","ykShMtNgDB1","uafqZbOYpVL","275482.0"],["2013","ykShMtNgDB1","X5MzEu84hUN","224568.0"],["2013","ykShMtNgDB1","ouZ5YpZ4T3a","301633.0"],["2013","Yut5amdi7iw","PF4defRibDi","181321.0"],["2013","Yut5amdi7iw","WB7EAwS3F8N","30791.0"],["2014","Yut5amdi7iw","zfwo4rq1XC3","103770.0"],["2014","Yut5amdi7iw","m2ux1UEElNB","100038.0"],["2013","ykShMtNgDB1","mKI72g04l0D","242101.0"],["2013","Yut5amdi7iw","PvqxGEssig9","97630.0"],["2013","Yut5amdi7iw","aiZstwpkrny","89742.0"],["2013","Yut5amdi7iw","QekURU8eIU0","196288.0"],["2014","ykShMtNgDB1","Qyg5jjxGeQD","310734.0"],["2013","Yut5amdi7iw","DWSo42hunXH","39369.0"],["2013","ykShMtNgDB1","AvfNRAIsvhg","308742.0"],["2013","ykShMtNgDB1","NzvekEmEzUG","98048.0"],["2014","Yut5amdi7iw","H2LvCkw2bCO","140531.0"],["2013","ykShMtNgDB1","ilY7TEjviqa","332441.0"],["2013","Yut5amdi7iw","vQvBfxn7Cjs","81602.0"],["2013","Yut5amdi7iw","dFCrIa5paz7","63282.0"],["2013","Yut5amdi7iw","uHp3aLKA6Tn","59441.0"],["2013","Yut5amdi7iw","cjlkhW8VMDO","12204.0"],["2013","Yut5amdi7iw","gOcZSwBmijY","138531.0"],["2013","ykShMtNgDB1","PHWaJvzTmL8","179048.0"],["2013","ykShMtNgDB1","jAI2fd8kK1z","362316.0"],["2013","ykShMtNgDB1","e3ATlebHNrD","395824.0"],["2014","Yut5amdi7iw","RHLUbsrsFoE","55076.0"],["2014","ykShMtNgDB1","P1TuGaaZ981","260319.0"],["2013","ykShMtNgDB1","jupsOTyKi1W","106034.0"],["2013","ykShMtNgDB1","QUTWca9YxNb","131269.0"],["2014","ykShMtNgDB1","f7UPzYMgzVH","385925.0"],["2014","Yut5amdi7iw","lnOyHhoLzre","600836.0"],["2013","Yut5amdi7iw","aa5sxEFiAwN","15859.0"],["2013","ykShMtNgDB1","yTTjcYh4xqa","275426.0"],["2014","ykShMtNgDB1","GOmwoDIGL98","87129.0"],["2013","ykShMtNgDB1","vo788oc0NEn","153019.0"],["2013","ykShMtNgDB1","oMao5qA3DBy","417788.0"],["2013","ykShMtNgDB1","Nc1C12TG69d","233678.0"],["2013","ykShMtNgDB1","sWOWPBvwNY2","951648.0"],["2014","Yut5amdi7iw","T3A9X81ABG3","25571.0"],["2013","Yut5amdi7iw","m2ux1UEElNB","10488.0"],["2013","ykShMtNgDB1","RD96nI1JXVV","2179618.0"],["2013","ykShMtNgDB1","cirtJ7KuNU0","94580.0"],["2014","ykShMtNgDB1","OzGGHqXQn5p","428584.0"],["2014","Yut5amdi7iw","IgTAEKMqKRe","424095.0"],["2013","ykShMtNgDB1","plSLZJGUHZb","230456.0"],["2014","Yut5amdi7iw","IZAkMaffRh8","138664.0"],["2014","ykShMtNgDB1","Yb483pDzzWj","166249.0"],["2014","ykShMtNgDB1","ppnbxB0TxjG","324800.0"],["2013","Yut5amdi7iw","yh0b4OAgg8z","7129.0"],["2014","Yut5amdi7iw","xBWOfftpkLT","108068.0"],["2013","ykShMtNgDB1","C96DDKK03pu","330033.0"],["2014","ykShMtNgDB1","LoPF5WqswyW","308229.0"],["2014","Yut5amdi7iw","gncV3iPt6Sk","214527.0"],["2013","Yut5amdi7iw","Qyg5jjxGeQD","99971.0"],["2014","Yut5amdi7iw","xRx7W86ElUH","15411.0"],["2013","Yut5amdi7iw","zHa2ohFrpPM","34740.0"],["2014","Yut5amdi7iw","NzVLQOcSJJU","88954.0"],["2013","Yut5amdi7iw","yz7jPBCDXlX","26190.0"],["2014","ykShMtNgDB1","MiLb81EwC7j","218250.0"],["2013","ykShMtNgDB1","aVLidCZ2RYk","184592.0"],["2013","Yut5amdi7iw","A3b5mw8DJYC","233799.0"],["2013","ykShMtNgDB1","wIjscdPZF3N","556765.0"],["2013","Yut5amdi7iw","RCDM6DotMZw","47581.0"],["2014","ykShMtNgDB1","ilY7TEjviqa","339834.0"],["2014","ykShMtNgDB1","et6lWc8GDHy","364210.0"],["2013","ykShMtNgDB1","cnsiTXSJqqF","95943.0"],["2014","Yut5amdi7iw","VMgrQWSVIYn","641864.0"],["2014","ykShMtNgDB1","e3ATlebHNrD","406656.0"],["2014","Yut5amdi7iw","FylvwNXCTAQ","142858.0"],["2014","Yut5amdi7iw","SnczTnCrk6d","114034.0"],["2014","ykShMtNgDB1","kZ6RlMnt2bp","2428464.0"],["2014","ykShMtNgDB1","qg5ySBw9X5l","1516285.0"],["2013","Yut5amdi7iw","YtVMnut7Foe","742662.0"],["2014","Yut5amdi7iw","lQOxGNRaklm","93015.0"],["2014","ykShMtNgDB1","saOGTLvMX4F","653359.0"],["2013","Yut5amdi7iw","vU0Qt1A5IDz","240546.0"],["2013","Yut5amdi7iw","cb9rqgLXFeh","5495.0"],["2014","ykShMtNgDB1","lQOxGNRaklm","402502.0"],["2013","Yut5amdi7iw","tLzrq5IZ23W","101153.0"],["2014","ykShMtNgDB1","A3b5mw8DJYC","2850758.0"],["2013","Yut5amdi7iw","O8O3HQdJWHX","38411.0"],["2014","ykShMtNgDB1","cirtJ7KuNU0","95339.0"],["2013","Yut5amdi7iw","IGSrsG5I54W","52850.0"],["2013","Yut5amdi7iw","V60DkMrlQ5Q","33143.0"],["2013","Yut5amdi7iw","e3ATlebHNrD","23738.0"],["2014","Yut5amdi7iw","qarQhOt2OEh","200544.0"],["2014","Yut5amdi7iw","Nc1C12TG69d","95416.0"],["2014","ykShMtNgDB1","cb9rqgLXFeh","325407.0"],["2014","Yut5amdi7iw","btLScg6XCBN","91218.0"],["2014","ykShMtNgDB1","LbM25p7KBDP","181277.0"],["2014","ykShMtNgDB1","fSZfOuCkmAb","197368.0"],["2013","ykShMtNgDB1","Y8sOGpb4AFE","187639.0"],["2014","Yut5amdi7iw","acZHYslyJLt","3918310.0"],["2014","ykShMtNgDB1","VMgrQWSVIYn","880359.0"],["2013","Yut5amdi7iw","OzGGHqXQn5p","193809.0"],["2014","ykShMtNgDB1","B9idcF4fOIW","123377.0"],["2013","ykShMtNgDB1","P1TuGaaZ981","252121.0"],["2014","Yut5amdi7iw","kZ6RlMnt2bp","512701.0"],["2013","ykShMtNgDB1","Qyg5jjxGeQD","303668.0"],["2014","Yut5amdi7iw","L5AfyN2zxns","26928.0"],["2013","Yut5amdi7iw","iEIdCVxSJct","14042.0"],["2013","Yut5amdi7iw","fSZfOuCkmAb","2460.0"],["2014","ykShMtNgDB1","Y8sOGpb4AFE","191046.0"],["2013","ykShMtNgDB1","rQS2cX4JH88","55225.0"],["2013","ykShMtNgDB1","V60DkMrlQ5Q","153878.0"],["2013","ykShMtNgDB1","VMgrQWSVIYn","872472.0"],["2014","Yut5amdi7iw","yz7jPBCDXlX","86234.0"]],"width":4,"height":751}';
        $jsonarr = json_decode($jsondata);
//        var_dump($jsonarr->metaData->names);exit;
        $attendenceArray = array();
        $populationArray = array();
        $i =0;
        foreach($jsonarr->rows as $data){
            if(in_array($jsonarr->metaData->names->$data[2],$departmentName)){
                if($jsonarr->metaData->names->$data[0] == $year){
                    $arr = array("year"=>$jsonarr->metaData->names->$data[0],
                                 "type"=>$jsonarr->metaData->names->$data[1],
                                 "area"=>$jsonarr->metaData->names->$data[2],
                                 "nurses"=> $dataArray[$jsonarr->metaData->names->$data[2]],
                                 "value" =>$data[3]
                    );
                    if($jsonarr->metaData->names->$data[1] == "Attendance in OPD"){
                        $attendenceArray[] = $arr;
                    }if($jsonarr->metaData->names->$data[1] == "Population"){
                        $populationArray[] = $arr;
                    }
                }
            }
            $i++;
        }
        return $this->render(
            'HrisNursingBundle:Population:employee.html.twig',
            array(
                'results' => $results,
                'forms'   => $formString,
                'title'   => $title,
                'levelchoice'=> $organisationUnit,
                'licensetitle' => $licensetitle,
                'departmentName' => $serializer->serialize($departmentName,'json'),
                'departmentData' => $serializer->serialize($departmentData,'json'),
                'count'  => count($departmentData),
                'carde'    => $cardetring,
                'licence'  => $licencestring,
                'population'  => $populationArray,
                'attendance'  => $attendenceArray,
                'year'      => $year,
                'report'    => $reportType,
                'regionString' => $regionString
            ));

    }

    /**
     * return nursing records
     *
     * @param $organisationUnit
     * @param $regionArray
     * @param $formArray
     * @param $NursingCadre
     * @param $licence
     * @return mixed
     */
    private function nursingRecords($regionArray, $formArray=array(),$NursingCadre,$licence,$organisationUnit)
    {

        $entityManager = $this->getDoctrine()->getManager();
        $resourceTableName = "_resource_all_fields";
        //checking if date range is selected

        if($NursingCadre == "Enrolled"){
            $cardequery = " AND R.edu_evel = 'Certificate' ";
        }elseif($NursingCadre == "Registered"){
            $cardequery = " AND R.edu_evel != 'Certificate' ";
        }else{
            $cardequery = "";
        }
        if($licence == "Licensed"){
            $licensequery = " AND R.reg_no != '' ";
        }elseif($licence == "NotLicensed"){
            $licensequery = " AND R.reg_no = '' ";
        }else{
            $licensequery = " ";
        }
        if(count($regionArray) == 0){
            $regionQuery = "";
        }else{
            $regionQuery = " AND R.level3_regions_departments_institutions_referrals IN ('".implode("', '", $regionArray)."') ";
        }
        //Query all history data and count by field option
        if($organisationUnit == 'Region'){
            $query = "SELECT level3_regions_departments_institutions_referrals as data, count(level3_regions_departments_institutions_referrals) as total ";
        }else{
            $query = "SELECT level4_districts_reg_hospitals as data, count(level3_regions_departments_institutions_referrals) as total ";
        }
        $query .= "FROM ".$resourceTableName." R ";
        $query .= "INNER JOIN hris_record as V on V.instance = R.instance ";
        if(count($formArray) != 0){
            $query .= " WHERE V.form_id IN (".implode(",", $formArray).") AND R.profession = 'Nurse'  AND R.level3_regions_departments_institutions_referrals like '%Region' ".$cardequery.$licensequery.$regionQuery;
        }else{
            $query .= " WHERE R.profession = 'Nurse' AND R.level3_regions_departments_institutions_referrals like '%Region' ".$cardequery.$licensequery.$regionQuery;
        }
        $query .= " GROUP BY data ";

//        echo $query; die();
        //get the records
        $report = $entityManager -> getConnection() -> executeQuery($query) -> fetchAll();
        return $report;
    }
}
